@@ -1,7 +1,8 @@
 import ctypes
+import typing as t
 
 
-def bindEvents(structure, *methods):
+def bind_events(structure: ctypes.Structure, *methods: t.List[t.Callable[..., None]]):
     contents = structure()
     for index, (name, func) in enumerate(structure._fields_):
         setattr(contents, name, func(methods[index]))
